"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.solNetworkChainToGenesisHash = exports.solGenesisHashToNetworkChainPair = exports.evmNetworkChainToEvmChainId = exports.evmChainIdToNetworkChainPair = exports.isPlatform = exports.chainToPlatform = exports.platformToChains = exports.platforms = void 0;
const utils_1 = require("../utils");
const platformAndChainsEntries = [
    [
        "Evm",
        [
            "Ethereum",
            "Bsc",
            "Polygon",
            "Avalanche",
            "Oasis",
            "Aurora",
            "Fantom",
            "Karura",
            "Acala",
            "Klaytn",
            "Celo",
            "Moonbeam",
            "Neon",
            "Arbitrum",
            "Optimism",
            "Gnosis",
            "Base",
            "Sepolia",
        ],
    ],
    ["Solana", ["Solana", "Pythnet"]],
    ["Cosmwasm", ["Terra", "Terra2", "Injective", "Xpla", "Sei"]],
    ["Btc", ["Btc"]],
    ["Algorand", ["Algorand"]],
    ["Sui", ["Sui"]],
    ["Aptos", ["Aptos"]],
    ["Osmosis", ["Osmosis"]],
    ["Wormchain", ["Wormchain"]],
    ["Near", ["Near"]],
];
exports.platforms = (0, utils_1.column)(platformAndChainsEntries, 0);
exports.platformToChains = (0, utils_1.constMap)(platformAndChainsEntries);
exports.chainToPlatform = (0, utils_1.constMap)(platformAndChainsEntries, [1, 0]);
const isPlatform = (platform) => exports.platformToChains.has(platform);
exports.isPlatform = isPlatform;
const networkChainEvmCIdEntries = [
    [
        "Mainnet",
        [
            ["Ethereum", 1n],
            // TODO: forced to add this to match other list
            ["Sepolia", 0n],
            ["Bsc", 56n],
            ["Polygon", 137n],
            ["Avalanche", 43114n],
            ["Oasis", 42262n],
            ["Aurora", 1313161554n],
            ["Fantom", 250n],
            ["Karura", 686n],
            ["Acala", 787n],
            ["Klaytn", 8217n],
            ["Celo", 42220n],
            ["Moonbeam", 1284n],
            ["Neon", 245022934n],
            ["Arbitrum", 42161n],
            ["Optimism", 10n],
            ["Gnosis", 100n],
            ["Base", 8453n],
        ],
    ],
    [
        "Testnet",
        [
            ["Ethereum", 5n],
            ["Sepolia", 11155111n],
            ["Bsc", 97n],
            ["Polygon", 80001n],
            ["Avalanche", 43113n],
            ["Oasis", 42261n],
            ["Aurora", 1313161555n],
            ["Fantom", 4002n],
            ["Karura", 596n],
            ["Acala", 597n],
            ["Klaytn", 1001n],
            ["Celo", 44787n],
            ["Moonbeam", 1287n],
            ["Neon", 245022940n],
            ["Arbitrum", 421613n],
            ["Optimism", 420n],
            ["Gnosis", 77n],
            ["Base", 84531n],
        ],
    ],
];
exports.evmChainIdToNetworkChainPair = (0, utils_1.constMap)(networkChainEvmCIdEntries, [2, [0, 1]]);
exports.evmNetworkChainToEvmChainId = (0, utils_1.constMap)(networkChainEvmCIdEntries);
const networkChainSolanaGenesisHashes = [
    ["Mainnet", [["Solana", "5eykt4UsFv8P8NJdTREpY1vzqKqZKvdpKuc147dw2N9d"]]],
    ["Testnet", [["Solana", "EtWTRABZaYq6iMfeYKouRu166VU2xqa1wcaWoxPkrZBG"]]], // Note: this is referred to as `devnet` in sol
];
exports.solGenesisHashToNetworkChainPair = (0, utils_1.constMap)(networkChainSolanaGenesisHashes, [2, [0, 1]]);
exports.solNetworkChainToGenesisHash = (0, utils_1.constMap)(networkChainSolanaGenesisHashes);
//# sourceMappingURL=platforms.js.map